from __future__ import print_function
import numpy as np
import pickle
from ase.io import read
from gpaw import restart
from transport.lcao.principallayer import PrincipalSelfEnergy
from transport.greenfunction import RecursiveGF
from matplotlib import pyplot as plt

energies = np.arange(-2, 2, 0.1)

atoms = read('scatt.xyz')
patoms, pcalc = restart('leads.gpw',txt=None)
H_kMM, S_kMM = pickle.load(open('hs_leads_k.pckl','rb'))
hs_list_ii, hs_list_ij = pickle.load(open('hs_scatt_lists.pckl','rb'))

eta = 1e-5

RSE = [PrincipalSelfEnergy(pcalc, scatt=atoms, id=0),
       PrincipalSelfEnergy(pcalc, scatt=atoms, id=1)]

for selfenergy in RSE:
    selfenergy.set(eta=eta)
    selfenergy.initialize(H_kMM, S_kMM)
    
RGF = RecursiveGF(selfenergies=RSE)

RGF.set(eta=eta, align_bf=0)
RGF.initialize(hs_list_ii, hs_list_ij)

#dV = np.load('dV.npy')
#RGF.add_screening(dV)

import time

start = time.time()
T_e = RGF.get_transmission(energies)
end = time.time()
print(end - start)

#pickle.dump((energies, T_e), open('ET.pckl', 'wb'), 2)
plt.semilogy(energies,T_e)
plt.savefig('ET.png')
plt.close()

