from __future__ import print_function
import numpy as np
import pickle
#from transport.calculators import TransportCalculator
from gpaw import GPAW
#from transport.lcao.principallayer import PrincipalSelfEnergy as PS
#from transport.greenfunction import RecursiveGF, GreenFunction
#from transport import mpi
from transport.coupledhamiltonian import set_pzd_carbons
from transport.tk_gpaw import get_bfs_indices
from transport.calculators import TransportCalculator
from matplotlib import pyplot as plt

energies = np.arange(-4, 3, 0.01)

h, s = pickle.load(open('hs_scat.pckl','rb'))
h1, s1 = pickle.load(open('hs_princ.pckl','rb'))
scalc = GPAW('scatt.gpw',txt=None)

indices_C = np.where(scalc.atoms.symbols=='C')[0]

tcalc = TransportCalculator(h=h.astype(complex),s=s.astype(complex),
        h1=h1,s1=s1,align_bf=0)

tcalc.initialize()

gf = tcalc.greenfunction

#Subdiagonalize carbons and take pzd indices.

#bfs_pzd = set_pzd_carbons(scalc, gf, apply=False)

ext_C = [71,77] 
int_C = [74,75,76,79]
Ce = [3,6,7,10,12]
Ci = [3,6,10,12]
bfs_pzd = set_pzd_carbons(scalc, gf, ext_C=ext_C, int_C=int_C, 
                          Ce=Ce, Ci=Ci, apply=False)

#Add Au and N
Au_and_N = np.where((scalc.atoms.symbols=='Au')|(scalc.atoms.symbols=='N'))[0]
bfs_Au_and_N = get_bfs_indices(scalc, Au_and_N)
bfs_m = np.union1d(bfs_Au_and_N, bfs_pzd)

#Take subspace
gf.take_bfs(bfs_m, apply=True)
assert gf.H.shape[0] == len(bfs_Au_and_N)+len(bfs_pzd)


#### OLD #####
##lambda sets active. cutoff sets effective active space
#h_imp,s_imp=gf.take_bfs_activespace(scalc, indices_C, lambda x: abs(x)<3.5, cutoff=0.5)
#print(h_imp.diagonal())
#tcalc.set(energies=energies)
#tcalc.update()
#############

tcalc.set(energies=energies)
T_e = tcalc.get_transmission()

pickle.dump((tcalc.energies, tcalc.T_e), open('ET_pzd.pckl', 'wb'), 2)
plt.semilogy(tcalc.energies, tcalc.T_e)
plt.savefig('ET_pzd.png')
plt.close()
