#!/usr/bin/env python

import numpy as np
from matplotlib import pyplot as plt
import pickle
from gpaw import GPAW

from transport.calculators import TransportCalculator

scalc = GPAW('scatt.gpw', txt=None)


# In[5]:


h,s=pickle.load(open('hs_scat.pckl','rb'))
h1,s1=pickle.load(open('hs_princ.pckl','rb'))


indices_C = np.where(scalc.atoms.symbols=='C')[0]
indices_N = np.where(scalc.atoms.symbols=='N')[0]
indices_C_and_N = np.where((scalc.atoms.symbols=='C')|(scalc.atoms.symbols=='N'))[0]

tcalc = TransportCalculator(h=h.astype(complex),s=s.astype(complex),h1=h1,s1=s1,align_bf=0)

tcalc.initialize()

gf = tcalc.greenfunction

#gf.get_activespace(scalc, indices_C_and_N, cutoff=3.5, orthogonal=True)
gf.get_activespace(scalc, indices_C, lambda x: abs(x)<3.5, orthogonal=True)
energies = np.arange(-4,3,0.03)

dos=np.zeros_like(energies)
for e, energy in enumerate(energies):
    dos[e] = tcalc.greenfunction.dos(energy)

pickle.dump((energies,dos),open('EDosEmb_U2_ON.pckl','wb'),2)
plt.plot(energies,dos)
plt.show()
plt.savefig('EDosEmb_U2_ON.png')
plt.close()



