from __future__ import print_function

from ase import *
from ase.io import read, write
from gpaw import *
import pickle
from gpaw.lcao.tools import remove_pbc, get_lead_lcao_hamiltonian
from gpaw.mpi import rank, MASTER

atoms = read('princ.xyz')

calc = GPAW(h=0.2,
            xc='PBE',
            basis='dzp',
            occupations=FermiDirac(width=0.),
            kpts={'size': (4, 1, 1), 'gamma': True},
            mode='lcao',
            txt='princ.txt',
            mixer=Mixer(0.1, 5, weight=100.0),
            symmetry={'point_group': False, 'time_reversal': True})

atoms.set_calculator(calc)
atoms.get_potential_energy()
calc.write('lcao_princ.gpw')

fermi = calc.get_fermi_level()
print(repr(fermi), file=open('fermi_princ.txt', 'w'))

tkpts_kc, tweights_k, H_skMM, S_kMM = get_lead_lcao_hamiltonian(
    calc, direction='x')
if rank == MASTER:
    S = S_kMM[0]
    H = H_skMM[0, 0] - fermi * S
    remove_pbc(atoms, H, S, d=0)
    pickle.dump((H, S), open('hs_princ.pckl', 'wb'), 2)
