from __future__ import print_function

from ase import *
from ase.io import read, write
from gpaw import *
import pickle
from gpaw.lcao.tools import remove_pbc, get_lcao_hamiltonian
from gpaw.mpi import rank, MASTER

atoms = read('scatt.xyz')

calc = GPAW(h=0.2,
            xc='PBE',
            basis='dzp',
            occupations=FermiDirac(width=0.),
            kpts={'size': (1, 1, 1), 'gamma': True},
            mode='lcao',
            txt='scatt.txt',
            mixer=Mixer(0.1, 5, weight=100.0),
            symmetry={'point_group': False, 'time_reversal': True})

atoms.set_calculator(calc)
atoms.get_potential_energy()
calc.write('lcao_scatt.gpw')

fermi = calc.get_fermi_level()
print(repr(fermi), file=open('fermi_scatt.txt', 'w'))

if rank == MASTER:
    H_skMM, S_kMM = get_lcao_hamiltonian(calc)
    #lcao = LCAOwrap(calc)
    #H = lcao.get_hamiltonian()
    #S = lcao.get_overlap()
    H = H_skMM[0,0] - fermi * S_kMM[0]
    S = S_kMM[0]
    remove_pbc(atoms, H, S, d=0)
    pickle.dump((H, S), open('hs_scat.pckl', 'wb'), 2)

