from __future__ import print_function
import numpy as np
import pickle as pickle
from transport.calculators import TransportCalculator
from matplotlib import pyplot as plt
from transport.mpi import rank
from gpaw import GPAW

energies = np.arange(-2., 2., 0.01)
H, S = pickle.load(open('hs_scat.pckl','rb'))
H1, S1 = pickle.load(open('hs_princ.pckl','rb'))
scalc = GPAW('lcao_scatt.gpw',txt=None)

tcalc = TransportCalculator(h=H.astype(np.complex64),
                            s=S.astype(np.complex64),
                            h1=H1.astype(np.complex64),
                            s1=S1.astype(np.complex64),
                            align_bf=0)
tcalc.initialize()
GF=tcalc.greenfunction
h_imp, s_imp = GF.take_bfs_activespace(scalc, range(len(scalc.atoms)) , lambda x: abs(x)<3.5)
print(len(h_imp))
tcalc.set(energies=energies)
T = tcalc.get_transmission()

if rank==0:
    pickle.dump((energies, T), open('ET_pz.pckl', 'wb'), 2)
    plt.plot(energies,T)
    plt.savefig('ET_pz.png')
    plt.close()

